Module protocols

Module protocols 

Implementations of the Protocol trait for two-party topic handshake and sync.

Structs

LogSync
Efficient sync protocol for append-only log data types.
LogSyncMetrics
Sync metrics emitted in event messages.
LogSyncSink
Sink wrapper which converts messages and errors into the expected types.
TopicHandshakeAcceptor
Acceptor side of the topic handshake protocol.
TopicHandshakeInitiator
Initiator side of the topic handshake protocol.
TopicLogSync
Protocol for synchronizing logs which are associated with a generic T topic.
TopicLogSyncLiveMetrics
Sync metrics emitted in event messages.

Enums

LogSyncError
Protocol error types.
LogSyncEvent
Events emitted from log sync sessions.
LogSyncMessage
Protocol messages.
LogSyncStatus
Sync status variants sent on log sync events.
TopicHandshakeError
Protocol error types.
TopicHandshakeEvent
Events emitted from topic handshake protocol sessions.
TopicHandshakeMessage
Protocol message types.
TopicLogSyncChannelError
Error type occurring in topic log sync channels.
TopicLogSyncError
Error type occurring in topic log sync protocol.
TopicLogSyncEvent
Events emitted from topic log sync sessions.
TopicLogSyncMessage
Protocol message types.

Traits

ShortFormat
Returns a displayable string representing the underlying value in a short format, easy to read during debugging and logging.

Type Aliases

Logs
A map of author logs.