TopicLogSyncEvent

Enum TopicLogSyncEvent 

pub enum TopicLogSyncEvent<E = ()> {
    SessionStarted,
    SyncStarted {
        metrics: Metrics,
    },
    SyncFinished {
        metrics: Metrics,
    },
    LiveModeStarted,
    OperationReceived {
        operation: Box<Operation<E>>,
        metrics: Metrics,
    },
    SessionFinished {
        metrics: Metrics,
    },
    Failed {
        error: String,
    },
}
Events emitted from topic log sync sessions.

Variants



SessionStarted

A session has been initiated locally.

This event is always sent and will be followed by SyncStarted or Failed events.



SyncStarted

We have exchanged initial session metrics with the remote and the sync phase of this session has started.

This event will be followed by any number of OperationReceived events, or a SyncFinished or Failed.

Fields

metrics: Metrics


SyncFinished

All past state has been replicated and we will now enter live mode LiveModeStarted (if configured) or the session will end SessionFinished.

This event will be followed by a LiveModeStarted event or a SyncFinished or Failed event.

Fields

metrics: Metrics


LiveModeStarted

The session has entered live mode, we will send and receive operations in realtime.

This event will be followed by any number of OperationReceived events or a SyncFinished or Failed event.



OperationReceived

An operation has been received, this can be in the “sync” or “live mode” phase of a session.

Fields

operation: Box<Operation<E>>
metrics: Metrics


SessionFinished

The session has finished.

When no error occurs this event will always be sent at the end of a session.

Fields

metrics: Metrics


Failed

The session failed.

This event will always be the final event sent when an error occurred in any phase of the session.

Fields

error: String