ShortFormat

Trait ShortFormat 

pub trait ShortFormat {
    // Required method
    fn fmt_short(&self) -> String;
}
Returns a displayable string representing the underlying value in a short format, easy to read during debugging and logging.

Required Methods

fn fmt_short(&self) -> String

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ShortFormat for Hash

Source

impl ShortFormat for VerifyingKey

Implementors