pub struct TopicSyncManager<T, S, L, E>where
T: Clone,
E: Extensions,{ /* private fields */ }Expand description
Create and manage topic log sync sessions.
Sync sessions are created via the manager, which instantiates them with access to the shared topic map and operation store as well as channels for receiving sync events and for sending newly arriving operations in live mode.
A handle can be acquired to a sync session via the session_handle method for sending any live mode operations to a specific session. It’s expected that users map sessions (by their id) to any topic subscriptions in order to understand the correct mappings.
There are two points where message deduplication occurs; 1) per-subscription deduplication of received operations across all sessions for this manager occurs in the event stream 2) per-session deduplication occurs on sending operations to a remote, this is especially required during live-mode when we may receive the same new operation from several sources. The former stops any local consumers from receiving the same operation more than once, the latter reduces unnecessary noise on the network.
Implementations
Sourceimpl<T, S, L, E> TopicSyncManager<T, S, L, E>where
T: Clone,
E: Extensions,
impl<T, S, L, E> TopicSyncManager<T, S, L, E>where
T: Clone,
E: Extensions,