Implementations of the Protocol trait for two-party topic handshake and sync.
Structs
- LogSync
- Efficient sync protocol for append-only log data types.
- LogSync
Metrics - Sync metrics emitted in event messages.
- LogSync
Sink - Sink wrapper which converts messages and errors into the expected types.
- Topic
Handshake Acceptor - Acceptor side of the topic handshake protocol.
- Topic
Handshake Initiator - Initiator side of the topic handshake protocol.
- Topic
LogSync - Protocol for synchronizing logs which are associated with a generic T topic.
- Topic
LogSync Live Metrics - Sync metrics emitted in event messages.
Enums
- LogSync
Error - Protocol error types.
- LogSync
Event - Events emitted from log sync sessions.
- LogSync
Message - Protocol messages.
- LogSync
Status - Sync status variants sent on log sync events.
- Topic
Handshake Error - Protocol error types.
- Topic
Handshake Event - Events emitted from topic handshake protocol sessions.
- Topic
Handshake Message - Protocol message types.
- Topic
LogSync Channel Error - Error type occurring in topic log sync channels.
- Topic
LogSync Error - Error type occurring in topic log sync protocol.
- Topic
LogSync Event - Events emitted from topic log sync sessions.
- Topic
LogSync Message - Protocol message types.
Traits
- Short
Format - Returns a displayable string representing the underlying value in a short format, easy to read during debugging and logging.
Type Aliases
- Logs
- A map of author logs.