pub enum LogSyncEvent<E> {
MetricsExchanged {
metrics: LogSyncMetrics,
},
OperationReceived {
operation: Box<Operation<E>>,
metrics: LogSyncMetrics,
},
}Expand description
Events emitted from log sync sessions.
Variants
MetricsExchanged
We have calculated and sent the estimated bytes and operations to be sent during this sync session and received the remotes’ estimates.
This is the first event to occur and will only be sent once.
Fields

metrics: LogSyncMetricsOperationReceived
An operation has been received from the remote.