pub trait ShortFormat {
// Required method
fn fmt_short(&self) -> String;
}Expand description
Returns a displayable string representing the underlying value in a short format, easy to read during debugging and logging.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".