pub trait ShortFormat { // Required method fn fmt_short(&self) -> String; }
Returns a displayable string representing the underlying value in a short format, easy to read during debugging and logging.